<?php

namespace Litecms\Franchise\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Franchise\Models\Franchise;

class FranchisePolicy
{

    /**
     * Determine if the given user can view the franchise.
     *
     * @param UserPolicy $user
     * @param Franchise $franchise
     *
     * @return bool
     */
    public function view(UserPolicy $user, Franchise $franchise)
    {
        if ($user->canDo('franchise.franchise.view') && $user->isAdmin()) {
            return true;
        }

        return $franchise->user_id == user_id() && $franchise->user_type == user_type();
    }

    /**
     * Determine if the given user can create a franchise.
     *
     * @param UserPolicy $user
     * @param Franchise $franchise
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('franchise.franchise.create');
    }

    /**
     * Determine if the given user can update the given franchise.
     *
     * @param UserPolicy $user
     * @param Franchise $franchise
     *
     * @return bool
     */
    public function update(UserPolicy $user, Franchise $franchise)
    {
        if ($user->canDo('franchise.franchise.edit') && $user->isAdmin()) {
            return true;
        }

        return $franchise->user_id == user_id() && $franchise->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given franchise.
     *
     * @param UserPolicy $user
     * @param Franchise $franchise
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Franchise $franchise)
    {
        return $franchise->user_id == user_id() && $franchise->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given franchise.
     *
     * @param UserPolicy $user
     * @param Franchise $franchise
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Franchise $franchise)
    {
        if ($user->canDo('franchise.franchise.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given franchise.
     *
     * @param UserPolicy $user
     * @param Franchise $franchise
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Franchise $franchise)
    {
        if ($user->canDo('franchise.franchise.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
